@@ -485,12 +485,16 @@ class Screen:
 
     # noinspection PyProtectedMember
     def remove(self, obj):
-        if obj in self._objects:
-            self._objects.remove(obj);
-        elif obj not in self._gridlines and obj not in self._helpers:
-            raise ValueError(f'Object: {obj} is not registered with the screen? Did you call the constructor?');
-        self._screen.cv.delete(obj._ref);
-        del obj;
+        # self._screen.cv.delete(obj._ref);
+        try:
+            self._canvas.delete(obj._ref)
+            if obj in self._objects:
+                self._objects.remove(obj);
+            else:
+                # print('possible error here')
+                pass;
+        except tk.TclError:
+            pass;
 
     def objects(self) -> tuple:
         """
